@@ -12,7 +12,7 @@ Dancer::Plugin::Database - easy database connections for Dancer applications
 
 =cut
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 
 my $settings = undef;
 
@@ -161,6 +161,12 @@ sub _get_connection {
         }
     }
 
+    # Indicate whether queries generated by quick_query() etc in
+    # Dancer::Plugin::Database::Handle should be logged or not; this seemed a
+    # little dirty, but DBI's docs encourage it
+    # ("You can stash private data into DBI handles via $h->{private_..._*}..")
+    $dbh->{_private_log_queries} = $settings->{log_queries};
+
     # Re-bless it as a Dancer::Plugin::Database::Handle object, to provide nice
     # extra features:
     return bless $dbh, 'Dancer::Plugin::Database::Handle';
@@ -298,6 +304,7 @@ should be specified as, for example:
                 RaiseError: 1
                 AutoCommit: 1
             on_connect_do: ["SET NAMES 'utf8'", "SET CHARACTER SET 'utf8'" ]
+            log_queries: 1
 
 The C<connection_check_threshold> setting is optional, if not provided, it
 will default to 30 seconds.  If the database keyword was last called more than
@@ -314,6 +321,13 @@ The optional C<on_connect_do> setting is an array of queries which should be
 performed when a connection is established; if given, each query will be
 performed using C<< $dbh->do >>.
 
+The optional C<log_queries> setting enables logging of queries generated by the
+helper functions C<quick_insert> et al in L<Dancer::Plugin::Database::Handle>.
+If you enable it, generated queries will be logged at 'debug' level.  Be aware
+that they will contain the data you're passing to/from the database, so be
+careful not to enable this option in production, where you could inadvertently
+log sensitive information.
+
 If you prefer, you can also supply a pre-crafted DSN using the C<dsn> setting;
 in that case, it will be used as-is, and the driver/database/host settings will 
 be ignored.  This may be useful if you're using some DBI driver which requires 
